card/cool_swiper_card_wrapper library

Classes

CoolSwiperCardWrapper
This widget is responsible for scaling up & sliding down the background cards of the the card being dragged to give the illusion that they replaced it