menu
cool_card_swiper package
documentation
card/cool_swiper_card_wrapper.dart
card/cool_swiper_card_wrapper.dart
dark_mode
light_mode
card/cool_swiper_card_wrapper
library
Classes
CoolSwiperCardWrapper
This widget is responsible for scaling up & sliding down the background cards of the the card being dragged to give the illusion that they replaced it
cool_card_swiper package
documentation
card/cool_swiper_card_wrapper.dart
cool_card_swiper
package
Libraries
card/cool_swiper
card/cool_swiper_card
card/cool_swiper_card_wrapper
cool_card_swiper
model/card_generator
utils/constants
utils/utils
cool_swiper_card_wrapper library